// components/VacationCard.tsx
import React from 'react';
import Image from 'next/image';

interface VacationCardProps {
  type: string;
  title: string;
  image: string;
  details: string[];
}

const VacationCard: React.FC<VacationCardProps> = ({ type, title, image, details }) => {
  return (
    <div className="bg-white rounded-lg shadow-lg p-4 w-80">
      <div className="flex items-start mb-2">
        <div className="w-1/3 mr-4">
          <Image src={image} alt={title} width={80} height={80} className="rounded-lg" />
        </div>
        <div className="w-2/3">
          <span className="inline-block bg-blue-100 text-blue-800 text-xs px-2 py-1 rounded-full mb-2">
            {type}
          </span>
          <h3 className="font-semibold text-lg mb-2">{title}</h3>
          <div className="text-sm text-gray-600 flex">
            {details.map((detail, index) => (
              <React.Fragment key={index}>
                <span>{detail}</span>
                {index < details.length - 1 && <span className="mx-2">|</span>}
              </React.Fragment>
            ))}
          </div>
        </div>
      </div>
      <div className="absolute top-2 right-2 flex flex-col">
        <span className="w-1 h-1 bg-gray-300 rounded-full mb-1"></span>
        <span className="w-1 h-1 bg-gray-300 rounded-full mb-1"></span>
        <span className="w-1 h-1 bg-gray-300 rounded-full"></span>
      </div>
    </div>
  );
};

export default VacationCard;